#
# spec file for package perl-URI-db
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name URI-db
Name:           perl-URI-db
Version:        0.230.0
Release:        1.2
# 0.23 -> normalize -> 0.230.0
%define cpan_version 0.23
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Database URIs
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/D/DW/DWHEELER/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Module::Build) >= 0.30
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(URI) >= 1.40
BuildRequires:  perl(URI::Nested) >= 0.10
Requires:       perl(URI) >= 1.40
Requires:       perl(URI::Nested) >= 0.10
Provides:       perl(URI::cassandra) = %{version}
Provides:       perl(URI::clickhouse) = 0.200.0
Provides:       perl(URI::cockroach) = %{version}
Provides:       perl(URI::cockroachdb) = %{version}
Provides:       perl(URI::couch) = %{version}
Provides:       perl(URI::couchdb) = %{version}
Provides:       perl(URI::cubrid) = %{version}
Provides:       perl(URI::db) = %{version}
Provides:       perl(URI::db2) = %{version}
Provides:       perl(URI::derby) = %{version}
Provides:       perl(URI::exasol) = %{version}
Provides:       perl(URI::firebird) = %{version}
Provides:       perl(URI::hive) = %{version}
Provides:       perl(URI::impala) = %{version}
Provides:       perl(URI::informix) = %{version}
Provides:       perl(URI::ingres) = %{version}
Provides:       perl(URI::interbase) = %{version}
Provides:       perl(URI::ldapdb) = %{version}
Provides:       perl(URI::maria) = %{version}
Provides:       perl(URI::mariadb) = %{version}
Provides:       perl(URI::max) = %{version}
Provides:       perl(URI::maxdb) = %{version}
Provides:       perl(URI::monet) = %{version}
Provides:       perl(URI::monetdb) = %{version}
Provides:       perl(URI::mongo) = %{version}
Provides:       perl(URI::mongodb) = %{version}
Provides:       perl(URI::mssql) = %{version}
Provides:       perl(URI::mysql) = %{version}
Provides:       perl(URI::oracle) = %{version}
Provides:       perl(URI::pg) = %{version}
Provides:       perl(URI::pgsql) = %{version}
Provides:       perl(URI::pgxc) = %{version}
Provides:       perl(URI::postgres) = %{version}
Provides:       perl(URI::postgresql) = %{version}
Provides:       perl(URI::postgresxc) = %{version}
Provides:       perl(URI::redshift) = %{version}
Provides:       perl(URI::snowflake) = %{version}
Provides:       perl(URI::sqlite) = %{version}
Provides:       perl(URI::sqlite3) = %{version}
Provides:       perl(URI::sqlserver) = %{version}
Provides:       perl(URI::sybase) = %{version}
Provides:       perl(URI::teradata) = %{version}
Provides:       perl(URI::unify) = %{version}
Provides:       perl(URI::vertica) = %{version}
Provides:       perl(URI::yugabyte) = %{version}
Provides:       perl(URI::yugabytedb) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
Database URIs

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Build.PL --installdirs=vendor
./Build build --flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install --destdir=%{buildroot} --create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README README.md

%changelog
* Thu Jan  9 2025 Tina Müller <timueller+perl@suse.de>
- updated to 0.230.0 (0.23)
  see /usr/share/doc/packages/perl-URI-db/Changes
  0.23 2025-01-09T02:48:06Z
  - Added URI::clickhouse. Thanks to Ilia Rassadin for the PR (#18).
  - Changed the MySQL (and MariaDB) URI `dbi_dsn()` method to use
    DBD::MariaDB instead of DBD::mysql, because it better supports older
    MySQL client libraries and improves Unicode support.
* Fri Apr  5 2024 Tina Müller <timueller+perl@suse.de>
- updated to 0.22
  see /usr/share/doc/packages/perl-URI-db/Changes
  0.22 2024-04-05T01:38:17Z
  - Changed Oracle database DBI parameter generation as follows:
  - If there is not a hostname or port, just use the raw SID or service
    name as the database name: `dbi:Oracle:$name`. This is way 1 in the
    DBD::Oracle documentation
  - If there is a hostname or port, use the EZCONNECT syntax. This is
    way 3 in the DBD::Oracle documentation.
    Use of a port without a host name may not be valid, but it seems most
    prudent to build an EZCONNECT that includes the port in this context
    and to let Oracle or DBD::Oracle reject it if appropriate. Thanks
    again to @vectro for the and diligence, testing, and patience with
    this issue  (#22).
* Wed May 10 2023 Tina Müller <timueller+perl@suse.de>
- updated to 0.21
  see /usr/share/doc/packages/perl-URI-db/Changes
  0.21 2023-05-09T22:18:52Z
  - Changed Oracle database DBI parameter name from `sid` to
    `service_name`. Thanks to @vectro for the report (#22).
* Tue Jun 21 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.20
  see /usr/share/doc/packages/perl-URI-db/Changes
  0.20  2022-06-20T17:48:44Z
  - Added URI::cockroach and URI::yugabyte.
* Fri Jul 20 2018 coolo@suse.com
- updated to 0.19
  see /usr/share/doc/packages/perl-URI-db/Changes
  0.19  2018-07-19T15:15:04Z
  - Added URI::snowflake.
* Sat Nov  4 2017 coolo@suse.com
- updated to 0.18
  see /usr/share/doc/packages/perl-URI-db/Changes
  0.18  2017-11-03T15:01:43Z
  - Added URI::redshift to support db:redshift: URIs, thanks to a pull
    request from Steve Caldwell (PR #12).
  - Added URI::exasol, thanks to Johan Wärlander.
* Sun Feb  7 2016 coolo@suse.com
- updated to 0.17
  see /usr/share/doc/packages/perl-URI-db/Changes
  0.17  2016-02-03T18:35:33Z
  - Added URI::_ado, which subclasses URI::_odbc to provide a `dbi_dsn()`
    that returns a DSN using DBD::ADO. NOTE: This class is experimental,
    since I was unable to figure out the best default values for the
    connection string -- there are so many options! Feedback and
    recommendations wanted (Issue #11).
  - The `dbi_dsn` method of URI::mssql now supports a single argument to
    specify the DBI driver for which to return a DSN. Pass in "sybase" or
    "ado" (experimental) to get a DSN for either of those drivers,
    instead. Based on work by Dan Muey.
* Tue Sep 22 2015 coolo@suse.com
- updated to 0.16
  see /usr/share/doc/packages/perl-URI-db/Changes
  0.16  2015-09-22T00:17:07Z
  - Added new abstract class, URI::_odbc, for URIs that use ODBC in
    `dbi_dsn`.
  - The `dbi_dsn` method of URI::mssql now returns an ODBC DSN instead of
    DBD::Sybase, since the latter would require Sybase to build.
  - URI::sqlserver now inherits from URI::mssql rather than the other way
    around.
  - Fixed a bug where a URI with three slashes but no authority part after
    the first two would incorrectly think the databse name should be an
    absolute path. That is, in "db:sqlite:///foo.db", the `dbname` value
    is "foo.db", not "/foo.db". Thanks to Dan Book for the report
    (issue #8).
* Tue Apr 14 2015 coolo@suse.com
- initial package $version
  * created by $NAME $VERSION
